# ==============================================================================
# run_coregage.R  -  Project driver script
# Project : TRIAL_ABC
# Created : auto-generated by rCoreGage::create_project()
# ==============================================================================

library(rCoreGage)

source("rules/config/project_config.R")

coregage_run <- function(cfg) {

  message("========== CoreGage : Starting Run ==========")
  message("  Project : ", cfg$project_name)

  state           <- setup_coregage(cfg)
  state$domains   <- load_inputs(cfg)
  message("   Domains: ", paste(toupper(names(state$domains)), collapse=", "))
  state           <- run_checks(cfg, state)
  build_reports(cfg, state)

  message("========== CoreGage : Run Complete ==========")
  message(">> Reports: ", cfg$reports)
}

coregage_run(cfg)
